@@ -37,12 +37,11 @@ class PDFSheet:
         for idx, block in enumerate(self.data_list):
             cur_col = (idx / self.rows) % self.cols
             cur_row = idx % self.rows
-            if cur_col == 0:
-                ladj = self.left_adj
-            else:
-                ladj = 0
+            # if cur_col == 0:
+            #     ladj = self.left_adj
+            # else:
+            #     ladj = 0
 
-            
             origin = (self.left_adj + cur_col * self.block_width,
                       (self.rows - cur_row - 1) * self.block_height)
 
